Index: trunk/IPs/systemC/Environment/Data/src/loadexec.c
===================================================================
--- trunk/IPs/systemC/Environment/Data/src/loadexec.c	(revision 113)
+++ trunk/IPs/systemC/Environment/Data/src/loadexec.c	(revision 117)
@@ -33,4 +33,5 @@
 #include <string.h>
 #include <bfd.h>
+#include "../../Common/include/Debug.h"
 
 #ifndef TRUE
@@ -110,20 +111,20 @@
 
    if (!exec) {
-      fprintf(stderr, "Cannot open File '%s'\n", file);
+      cerr("Cannot open File '%s'\n", file);
       exit(1);
    }
 
    if (bfd_check_format(exec, bfd_object) != TRUE && !(exec->flags & EXEC_P)) {
-      fprintf(stderr, "File %s is not an executable file\n",
-                       file); //bfd_get_filename(exec));
+      cerr("File %s is not an executable file\n",
+            file); //bfd_get_filename(exec));
       exit(1);
    }
 
-#if 1
-   printf("Loading sections ");
+#if 0
+   cout("Loading sections ");
    for (i = 0; sections[i]; i++)
-      printf("%s%s", sections[i], sections[i+1] ? ", " : " ");
-   printf("from \"%s\"\n",bfd_get_filename(exec));
-   //printf("of executable '%s' for '%s' architecture in format '%s'\n",
+     __cout("%s%s", sections[i], ((sections[i+1]!=NULL)?", ":" "));
+   __cout("from \"%s\"\n",bfd_get_filename(exec));
+   //cout("of executable '%s' for '%s' architecture in format '%s'\n",
    //        bfd_get_filename(exec), bfd_printable_name(exec), exec->xvec->name);
 #endif
